/**
 * Copyright (C) 2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.jclouds.cloudsigma;

import static org.jclouds.concurrent.MoreExecutors.sameThreadExecutor;

import org.apache.log4j.Logger;
import org.dasein.cloud.AbstractCloud;
import org.dasein.cloud.ProviderContext;
import org.dasein.cloud.jclouds.cloudsigma.compute.CSComputeServices;
import org.dasein.cloud.jclouds.cloudsigma.network.CSNetworkServices;
import org.jclouds.cloudsigma.CloudSigmaAsyncClient;
import org.jclouds.cloudsigma.CloudSigmaClient;
import org.jclouds.compute.ComputeServiceContextFactory;
import org.jclouds.concurrent.config.ExecutorServiceModule;
import org.jclouds.logging.log4j.config.Log4JLoggingModule;
import org.jclouds.rest.RestContext;

import com.google.common.collect.ImmutableSet;
import com.google.inject.Module;


public class CloudSigma extends AbstractCloud {
    static private final Logger logger = Logger.getLogger(CloudSigma.class);
    
    public String getCloudName() {
        return "CloudSigma";
    }

    public String getProviderName() {
        return "CloudSigma";
    }

    public RestContext<CloudSigmaClient,CloudSigmaAsyncClient> getCloudClient() {
        ProviderContext ctx = getContext();
        String user = new String(ctx.getAccessPublic());
        String key = new String(ctx.getAccessPrivate());
        
        return (new ComputeServiceContextFactory()).createContext("cloudsigma-zrh", user, key, ImmutableSet.<Module> of(new Log4JLoggingModule(), new ExecutorServiceModule(sameThreadExecutor(), sameThreadExecutor()))).getProviderSpecificContext();
    }
    
    @Override
    public CSComputeServices getComputeServices() {
        return new CSComputeServices(this);
    }
    
    @Override
    public CSDC getDataCenterServices() {
        return new CSDC(this);
    }
    
    @Override
    public CSNetworkServices getNetworkServices() {
        return new CSNetworkServices(this);
    }
    
    @Override
    public String testContext() {
        try {
            RestContext<CloudSigmaClient,CloudSigmaAsyncClient> ctx = getCloudClient();

            try {
                return ctx.getApi().getProfileInfo().getUuid();
            }
            finally {
                ctx.close();
            }
        }
        catch( Throwable t ) {
            logger.warn("Unable to test CloudSigma context for " + getContext().getAccountNumber() + ": " + t.getMessage());
            if( logger.isDebugEnabled() ) {
                t.printStackTrace();
            }
            return null;
        }
    }
}
